==> igniteui-react-layouts-18.0.0.tgz: package/esm2015/lib/igr-tool-action-event-detail.js <==
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionType_$type } from "igniteui-react-core";
import { ToolActionEventDetail as ToolActionEventDetail_internal } from "./ToolActionEventDetail";
import { ensureEnum, ensureBool } from "igniteui-react-core";
export class IgrToolActionEventDetail {
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new ToolActionEventDetail_internal();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get action() {
        if (this.i.a == null) {
            return null;
        }
        if (!this.i.a.externalObject) {
            let e = IgrToolAction._createFromInternal(this.i.a);
            if (e) {
                e._implementation = this.i.a;
            }
            this.i.a.externalObject = e;
        }
        return this.i.a.externalObject;
    }
    set action(v) {
        v == null ? this.i.a = null : this.i.a = v.i;
    }
    get actionType() {
        return this.i.b;
    }
    set actionType(v) {
        this.i.b = ensureEnum(ToolActionType_$type, v);
    }
    get isModified() {
        return this.i.d;
    }
    set isModified(v) {
        this.i.d = ensureBool(v);
    }
    get boolValue() {
        return this.i.c;
    }
    set boolValue(v) {
        this.i.c = ensureBool(v);
    }
    get numberValue() {
        return this.i.f;
    }
    set numberValue(v) {
        this.i.f = +v;
    }
    get dateTimeValue() {
        return this.i.e;
    }
    set dateTimeValue(v) {
        this.i.e = v;
    }
    get untypedValue() {
        return this.i.g;
    }
    set untypedValue(v) {
        this.i.g = v;
    }
    findByName(name) {
        if (this.action && this.action.name && this.action.name == name) {
            return this.action;
        }
        return null;
    }
}

==> igniteui-react-layouts-18.1.3.tgz: package/esm2015/lib/igr-tool-action-event-detail.js <==
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionType_$type } from "igniteui-react-core";
import { ToolActionEventDetail as ToolActionEventDetail_internal } from "./ToolActionEventDetail";
import { ensureEnum, ensureBool } from "igniteui-react-core";
export class IgrToolActionEventDetail {
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    createImplementation() {
        return new ToolActionEventDetail_internal();
    }
    /**
     * @hidden
     */
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get action() {
        const r = this.i.a;
        if (r == null) {
            return null;
        }
        if (!r.externalObject) {
            let e = IgrToolAction._createFromInternal(r);
            if (e) {
                e._implementation = r;
            }
            r.externalObject = e;
        }
        return r.externalObject;
    }
    set action(v) {
        v == null ? this.i.a = null : this.i.a = v.i;
    }
    get actionType() {
        return this.i.b;
    }
    set actionType(v) {
        this.i.b = ensureEnum(ToolActionType_$type, v);
    }
    get isModified() {
        return this.i.d;
    }
    set isModified(v) {
        this.i.d = ensureBool(v);
    }
    get boolValue() {
        return this.i.c;
    }
    set boolValue(v) {
        this.i.c = ensureBool(v);
    }
    get numberValue() {
        return this.i.f;
    }
    set numberValue(v) {
        this.i.f = +v;
    }
    get dateTimeValue() {
        return this.i.e;
    }
    set dateTimeValue(v) {
        this.i.e = v;
    }
    get untypedValue() {
        return this.i.g;
    }
    set untypedValue(v) {
        this.i.g = v;
    }
    findByName(name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        if (this.action && this.action.name && this.action.name == name) {
            return this.action;
        }
        return null;
    }
}
